﻿using System;

using Xamarin.Forms;
using Syncfusion.SfDataGrid.XForms;
using System.Collections.ObjectModel;
using System.Globalization;
using System.Collections.Generic;

namespace TestSyncFusion
{
    public class MyPage : ContentPage
    {
        public MyPage()
        {
            var sfgrid = new SfDataGrid();
           
            var data = new OrderInfoRepository();


            sfgrid.AutoGenerateColumns = false;

            var template = new GridTemplateColumn(){HeaderText = "Custom", MappingName = "OrderID"};
            var dataTemplate = new DataTemplate(() =>
            {

                var grid = new Grid()
                {
                    BackgroundColor = Color.Transparent,
                    Padding = 10,
                    RowSpacing = 20,
                };
                grid.ColumnDefinitions.Add(new ColumnDefinition() { Width = 60 });
                grid.ColumnDefinitions.Add(new ColumnDefinition() { Width = 60 });
                grid.ColumnDefinitions.Add(new ColumnDefinition() { Width = 70 });
                grid.ColumnDefinitions.Add(new ColumnDefinition() { Width = 60 });
                grid.ColumnDefinitions.Add(new ColumnDefinition() { Width = 70 });

                var label1 = new Label()
                {
                    TextColor = Color.Black,
                    HorizontalOptions = LayoutOptions.Center,
                    VerticalOptions = LayoutOptions.Center
                };
                label1.SetBinding(Label.TextProperty, "OrderID");
                label1.SetValue(Grid.ColumnProperty,0);

                var label2 = new Label()
                {
                    TextColor = Color.Black,
                    HorizontalOptions = LayoutOptions.Center,
                    VerticalOptions = LayoutOptions.Center
                };
                label2.SetBinding(Label.TextProperty, "CustomerID");
                label2.SetValue(Grid.ColumnProperty, 1);

                var label3 = new Label()
                {
                    TextColor = Color.Black,
                    HorizontalOptions = LayoutOptions.Center,
                    VerticalOptions = LayoutOptions.Center
                };
                label3.SetBinding(Label.TextProperty, "ShipCountry");
                label3.SetValue(Grid.ColumnProperty, 2);

                var label4 = new Label()
                {
                    TextColor = Color.Black,
                    HorizontalOptions = LayoutOptions.Center,
                    VerticalOptions = LayoutOptions.Center
                };
                label4.SetBinding(Label.TextProperty, "Customer");
                label4.SetValue(Grid.ColumnProperty, 3);

                var label5 = new Label()
                {
                    TextColor = Color.Black,
                    HorizontalOptions = LayoutOptions.Center,
                    VerticalOptions = LayoutOptions.Center
                };
                label5.SetBinding(Label.TextProperty, "ShipCity");
                label5.SetValue(Grid.ColumnProperty, 4);

                grid.Children.Add(label1);
                grid.Children.Add(label2);
                grid.Children.Add(label3);
                grid.Children.Add(label4);
                grid.Children.Add(label5);

                return grid;
            });

            template.CellTemplate = dataTemplate;
            sfgrid.Columns.Add(template);


            sfgrid.ColumnSizer = ColumnSizer.Star;

            sfgrid.ItemsSource = data.OrderInfoCollection;

            Content = sfgrid;

        }
    }

    public class OrderInfo
    {
        private int orderID;
        private string customerID;
        private string customer;
        private string shipCity;
        private string shipCountry;

        public int OrderID
        {
            get { return orderID; }
            set { this.orderID = value; }
        }

        public string CustomerID
        {
            get { return customerID; }
            set { this.customerID = value; }
        }

        public string ShipCountry
        {
            get { return shipCountry; }
            set { this.shipCountry = value; }
        }

        public string Customer
        {
            get { return this.customer; }
            set { this.customer = value; }
        }

        public string ShipCity
        {
            get { return shipCity; }
            set { this.shipCity = value; }
        }

        public OrderInfo(int orderId, string customerId, string country, string customer, string shipCity)
        {
            this.OrderID = orderId;
            this.CustomerID = customerId;
            this.Customer = customer;
            this.ShipCountry = country;
            this.ShipCity = shipCity;
        }
    }

    public class OrderInfoRepository
    {
        private ObservableCollection<OrderInfo> orderInfo;
        public ObservableCollection<OrderInfo> OrderInfoCollection
        {
            get { return orderInfo; }
            set { this.orderInfo = value; }
        }

        public OrderInfoRepository()
        {
            orderInfo = new ObservableCollection<OrderInfo>();
            this.GenerateOrders();
        }

        private void GenerateOrders()
        {
            orderInfo.Add(new OrderInfo(1001, "Maria Anders", "Germany", "ALFKI", "Berlin"));
            orderInfo.Add(new OrderInfo(1002, "Ana Trujilo", "Mexico", "ANATR", "México D.F."));
            orderInfo.Add(new OrderInfo(1003, "Ant Fuller", "Mexico", "ANTON", "México D.F."));
            orderInfo.Add(new OrderInfo(1004, "Thomas Hardy", "UK", "AROUT", "London"));
            orderInfo.Add(new OrderInfo(1005, "Tim Adams", "Sweden", "BERGS", "Luleå"));
            orderInfo.Add(new OrderInfo(1006, "Hanna Moos", "Germany", "BLAUS", "Mannheim"));
            orderInfo.Add(new OrderInfo(1007, "Andrew Fuller", "France", "BLONP", "Strasbourg"));
            orderInfo.Add(new OrderInfo(1008, "Martin King", "Spain", "BOLID", "Madrid"));
            orderInfo.Add(new OrderInfo(1009, "Lenny Lin", "France", "BONAP", "Marseille"));
            orderInfo.Add(new OrderInfo(1010, "John Carter", "Canada", "BOTTM", "Tsawassen"));
            orderInfo.Add(new OrderInfo(1011, "Lauro King", "UK", "AROUT", "London"));
            orderInfo.Add(new OrderInfo(1012, "Anne Wilson", "Germany", "BLAUS", "Mannheim"));
            orderInfo.Add(new OrderInfo(1013, "Alfki Kyle", "France", "BLONP", "Strasbourg"));
            orderInfo.Add(new OrderInfo(1014, "Gina Irene", "UK", "AROUT", "London"));
        }
    }

}

